@@ -62,10 +62,6 @@ BrightnessControl::BrightnessControl(QObject* parent)
     connect(globalAction, SIGNAL(triggered(bool)), SLOT(decreaseBrightness()));
 }
 
-BrightnessControl::~BrightnessControl()
-{
-}
-
 void BrightnessControl::onProfileUnload()
 {
     //
@@ -92,8 +88,10 @@ void BrightnessControl::onProfileLoad()
         // We don't want to change anything here
         qCDebug(POWERDEVIL) << "Not changing brightness, the current one is lower and the profile is more conservative";
     } else if (m_defaultValue >= 0) {
-        QVariantMap args;
-        args["Value"] = QVariant::fromValue((float)m_defaultValue);
+        const int absoluteValue = qRound(m_defaultValue / 100.0 * brightnessMax());
+        QVariantMap args{
+            {QStringLiteral("Value"), QVariant::fromValue(absoluteValue)}
+        };
 
         // plugging in/out the AC is always explicit
         if ((m_currentProfile == "AC" && m_lastProfile != "AC") ||
@@ -106,20 +104,13 @@ void BrightnessControl::onProfileLoad()
     }
 }
 
-void BrightnessControl::triggerImpl(const QVariantMap& args)
+void BrightnessControl::triggerImpl(const QVariantMap &args)
 {
-    int newBrightness = -1;
-    if (args.contains("Step")) {
-        backend()->setBrightnessStep(args["Step"].toInt());
-    } else if ((QMetaType::Type) args["Value"].type() == QMetaType::Int) {
-        backend()->setBrightnessValue(args["Value"].toInt());
-        newBrightness = brightnessPercent(args["Value"].toInt());
-    } else {
-        backend()->setBrightness(args["Value"].toFloat());
-        newBrightness = args["Value"].toFloat();
-    }
-    if (args["Explicit"].toBool() && !args["Silent"].toBool() && newBrightness > -1) {
-        BrightnessOSDWidget::show(newBrightness);
+    const int value = args.value(QStringLiteral("Value")).toInt();
+
+    backend()->setBrightness(value);
+    if (args.value(QStringLiteral("Explicit")).toBool() && !args.value(QStringLiteral("Silent")).toBool()) {
+        BrightnessOSDWidget::show(brightnessPercent(value));
     }
 }
 
@@ -143,8 +134,6 @@ bool BrightnessControl::loadAction(const KConfigGroup& config)
 
     if (config.hasKey("value")) {
         m_defaultValue = config.readEntry<int>("value", 50);
-    } else {
-        m_defaultValue = -1;
     }
 
     return true;
@@ -153,33 +142,36 @@ bool BrightnessControl::loadAction(const KConfigGroup& config)
 void BrightnessControl::onBrightnessChangedFromBackend(const BrightnessLogic::BrightnessInfo &info, BackendInterface::BrightnessControlType type)
 {
     if (type == BackendInterface::Screen) {
-        int brightness = qRound(info.percentage);
-        Q_EMIT brightnessValueChanged(info.value);
-        Q_EMIT brightnessStepChanged(info.step);
-        Q_EMIT brightnessChanged(brightness);
+        Q_EMIT brightnessChanged(info.value);
+        Q_EMIT brightnessMaxChanged(info.valueMax);
     }
 }
 
 int BrightnessControl::brightness() const
 {
-    return qRound(backend()->brightness());
+    return backend()->brightness();
 }
 
-void BrightnessControl::setBrightness(int percent)
+int BrightnessControl::brightnessMax() const
 {
-    QVariantMap args;
-    args["Value"] = QVariant::fromValue<float>((float)percent);
-    args["Explicit"] = true;
-    trigger(args);
+    return backend()->brightnessMax();
 }
 
-void BrightnessControl::setBrightnessSilent(int percent)
+void BrightnessControl::setBrightness(int value)
 {
-    QVariantMap args;
-    args["Value"] = QVariant::fromValue<float>((float)percent);
-    args["Explicit"] = true;
-    args["Silent"] = true;
-    trigger(args);
+    trigger({
+        {QStringLiteral("Value"), QVariant::fromValue(value)},
+        {QStringLiteral("Explicit"), true}
+    });
+}
+
+void BrightnessControl::setBrightnessSilent(int value)
+{
+    trigger({
+        {QStringLiteral("Value"), QVariant::fromValue(value)},
+        {QStringLiteral("Explicit"), true},
+        {QStringLiteral("Silent"), true}
+    });
 }
 
 void BrightnessControl::increaseBrightness()
@@ -198,54 +190,14 @@ void BrightnessControl::decreaseBrightness()
     }
 }
 
-int BrightnessControl::brightnessValue() const
+int BrightnessControl::brightnessSteps() const
 {
-    return backend()->brightnessValue();
-}
-
-int BrightnessControl::brightnessValueMax() const
-{
-    return backend()->brightnessValueMax();
-}
-
-void BrightnessControl::setBrightnessValue(int value)
-{
-    QVariantMap args;
-    args["Value"] = QVariant::fromValue<int>(value);
-    args["Explicit"] = true;
-    trigger(args);
-}
-
-void BrightnessControl::setBrightnessValueSilent(int value)
-{
-    QVariantMap args;
-    args["Value"] = QVariant::fromValue<int>(value);
-    args["Explicit"] = true;
-    args["Silent"] = true;
-    trigger(args);
-}
-
-int BrightnessControl::brightnessStep() const
-{
-    return backend()->brightnessStep();
-}
-
-int BrightnessControl::brightnessStepMax() const
-{
-    return backend()->brightnessStepMax();
-}
-
-void BrightnessControl::setBrightnessStep(int step)
-{
-    QVariantMap args;
-    args["Step"] = QVariant::fromValue<int>(step);
-    args["Explicit"] = true;
-    trigger(args);
+    return backend()->brightnessSteps();
 }
 
 int BrightnessControl::brightnessPercent(float value) const
 {
-    const float maxBrightness = brightnessValueMax();
+    const float maxBrightness = brightnessMax();
     if (maxBrightness <= 0) {
         return 0;
     }
