@@ -18,17 +18,16 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
  ***************************************************************************/
 
-#include <QtCore/QCoreApplication>
-#include <QtDBus/QDBusObjectPath>
-#include <QtDBus/QDBusArgument>
-#include <QtCore/QMetaType>
-#include <QtDBus/QDBusMetaType>
-
-#include <QtDBus/QDBusConnection>
-#include <QtDBus/QDBusInterface>
-#include <QtDBus/QDBusPendingReply>
-#include <QtDBus/QDBusConnectionInterface>
-#include <QtDBus/QDBusServiceWatcher>
+#include <QCoreApplication>
+#include <QDBusObjectPath>
+#include <QDBusArgument>
+#include <QMetaType>
+#include <QDBusMetaType>
+#include <QDBusConnection>
+#include <QDBusInterface>
+#include <QDBusPendingReply>
+#include <QDBusConnectionInterface>
+#include <QDBusServiceWatcher>
 
 #include "powerdevilpolicyagent.h"
 #include "powerdevil_debug.h"
@@ -58,6 +57,8 @@ const QDBusArgument &operator>>(const QDBusArgument &argument, NamedDBusObjectPa
 }
 
 Q_DECLARE_METATYPE(NamedDBusObjectPath)
+Q_DECLARE_METATYPE(InhibitionInfo)
+Q_DECLARE_METATYPE(QList<InhibitionInfo>)
 
 namespace PowerDevil
 {
@@ -104,6 +105,9 @@ PolicyAgent::~PolicyAgent()
 
 void PolicyAgent::init()
 {
+    qDBusRegisterMetaType<InhibitionInfo>();
+    qDBusRegisterMetaType<QList<InhibitionInfo>>();
+
     // Watch over the systemd service
     m_sdWatcher.data()->setConnection(QDBusConnection::systemBus());
     m_sdWatcher.data()->setWatchMode(QDBusServiceWatcher::WatchForUnregistration |
@@ -422,6 +426,8 @@ uint PolicyAgent::addInhibitionWithExplicitDBusService(uint types, const QString
 
     addInhibitionTypeHelper(m_lastCookie, static_cast< PolicyAgent::RequiredPolicies >(types));
 
+    emit InhibitionsChanged({ {qMakePair(appName, reason)} }, QStringList());
+
     return m_lastCookie;
 }
 
@@ -447,9 +453,13 @@ uint PolicyAgent::AddInhibition(uint types,
 
     addInhibitionTypeHelper(m_lastCookie, static_cast< PolicyAgent::RequiredPolicies >(types));
 
+    emit InhibitionsChanged({ {qMakePair(appName, reason)} }, QStringList());
+
     return m_lastCookie;
 }
 
+
+
 void PolicyAgent::addInhibitionTypeHelper(uint cookie, PolicyAgent::RequiredPolicies types)
 {
     // Look through all of the inhibition types
@@ -489,7 +499,10 @@ void PolicyAgent::addInhibitionTypeHelper(uint cookie, PolicyAgent::RequiredPoli
 void PolicyAgent::ReleaseInhibition(uint cookie)
 {
     qCDebug(POWERDEVIL) << "Released inhibition with cookie " << cookie;
+    emit InhibitionsChanged(QList<InhibitionInfo>(), { {m_cookieToAppName.value(cookie).first} });
     m_cookieToAppName.remove(cookie);
+
+
     QString service = m_cookieToBusService.take(cookie);
     if (!m_busWatcher.isNull() && !service.isEmpty() && !m_cookieToBusService.key(service)) {
         // no cookies from service left
@@ -526,6 +539,16 @@ void PolicyAgent::ReleaseInhibition(uint cookie)
     }
 }
 
+QList<InhibitionInfo> PolicyAgent::ListInhibitions() const
+{
+    return m_cookieToAppName.values();
+}
+
+bool PolicyAgent::HasInhibition(/*PolicyAgent::RequiredPolicies*/ uint types)
+{
+    return requirePolicyCheck(static_cast<PolicyAgent::RequiredPolicies>(types)) != PolicyAgent::None;
+}
+
 void PolicyAgent::releaseAllInhibitions()
 {
     QList< uint > allCookies = m_cookieToAppName.keys();
@@ -560,5 +583,3 @@ void PolicyAgent::setupSystemdInhibition()
 }
 
 }
-
-#include "powerdevilpolicyagent.moc"
